<?php

namespace App\Admin\Metrics;

use App\Models\User;
use App\Models\UserConsumeRecord;
use Carbon\Carbon;
use Dcat\Admin\Widgets\Metrics\Card;
use Illuminate\Contracts\Support\Renderable;
use Illuminate\Http\Request;

class Consume extends Card
{
    /**
     * 卡片底部内容.
     *
     * @var string|Renderable|\Closure
     */
    protected $footer;

    /**
     * 初始化卡片.
     */
    protected function init()
    {
        parent::init();

        $this->title('消费金币');
        $this->height(300);
        $this->dropdown([
            '1' => '当日新增消费金币',
            '7' => '7天新增消费金币',
            '30' => '当月新增消费金币',
            '-1' => '总消费金币',
        ]);
    }

    /**
     * 处理请求.
     *
     * @param Request $request
     *
     * @return void
     */
    public function handle(Request $request)
    {
        switch ($request->get('option')) {
            case '-1':
                $this->content($this->getConsume());
                break;
            case '7':
                $startAt = Carbon::now()->subDays(7)->toDateString().' 23:59:59';
                $endAt = Carbon::now()->toDateString().' 23:59:59';
                $today = $this->getConsume($startAt, $endAt);
                $this->content($today);

                break;
            case '30':
                $startAt = Carbon::now()->subDays(30)->toDateString().' 23:59:59';
                $endAt = Carbon::now()->toDateString().' 23:59:59';
                $today = $this->getConsume($startAt, $endAt);
                $this->content($today);

                break;
            case '1':
            default:
                $startAt = Carbon::now()->subDay()->toDateString().' 23:59:59';
                $endAt = Carbon::now()->toDateString().' 23:59:59';
                $today = $this->getConsume($startAt, $endAt);
                $this->content($today);
                break;
        }
    }


    private function getConsume($startAt = '', $endAt = ''): int
    {
        $res = UserConsumeRecord::when($startAt, function ($query) use ($startAt) {
            $query->where('created_at', '>', $startAt);
        })->when($endAt, function ($query) use ($endAt) {
            $query->where('created_at', '<=', $endAt);
        })->where('type', 2)
            ->sum('change');

        return abs($res);
    }

    /**
     * @param int $percent
     *
     * @return $this
     */
    public function up($percent)
    {
        return $this->footer(
            "<i class=\"feather icon-trending-up text-success\"></i> {$percent}% 增加"
        );
    }

    /**
     * @param int $percent
     *
     * @return $this
     */
    public function down($percent)
    {
        return $this->footer(
            "<i class=\"feather icon-trending-down text-danger\"></i> {$percent}% 减少"
        );
    }

    /**
     * 设置卡片底部内容.
     *
     * @param string|Renderable|\Closure $footer
     *
     * @return $this
     */
    public function footer($footer)
    {
        $this->footer = $footer;

        return $this;
    }

    /**
     * 渲染卡片内容.
     *
     * @return string
     */
    public function renderContent()
    {
        $content = parent::renderContent();

        return <<<HTML
<div class="d-flex justify-content-between align-items-center mt-1" style="margin-bottom: 2px">
    <h2 class="ml-1 font-lg-1">{$content}</h2>
</div>
<div class="ml-1 mt-1 font-weight-bold text-80">
    {$this->renderFooter()}
</div>
HTML;
    }

    /**
     * 渲染卡片底部内容.
     *
     * @return string
     */
    public function renderFooter()
    {
        return $this->toString($this->footer);
    }
}
